#!/usr/bin/env python
# coding: utf-8

# In[50]:


def generate_round_robin_odd(num_teams):
    '''Return a list orlists where results[i][j] gives
    the opponent of team i in round j.
    Note: num_teams must be odd.
    '''
    # Make an empty list of lists.
    results = [list(range(num_teams)) for i in range(num_teams)]

    # Initialize the list of teams.
    teams = list(range(num_teams))

    # Start the rounds.
    n2 = (num_teams - 1) // 2
    for round in range(num_teams):
        for i in range(n2):
            team1 = teams[n2 - i]
            team2 = teams[n2 + i + 1]
            results[team1][round] = team2
            results[team2][round] = team1

        # Set the team with the bye.
        results[teams[0]][round] = 'bye'

        # Rotate the array.
        rotate_list(teams)

    return results


# In[51]:


def rotate_list(teams):
    '''
    Rotate the entries one position.
    Move the last item to the front of the list.
    '''
    teams.insert(0, teams.pop())


# In[52]:


def generate_round_robin_even(num_teams):
    # Generate the result for one fewer teams.
    results = generate_round_robin_odd(num_teams - 1)

    # Copy the results into a bigger array,
    # replacing the byes with the extra team.
    results2 = [list(range(num_teams - 1)) for i in range(num_teams)]
    for team in range(num_teams - 1):
        for round in range(num_teams - 1):
            if results[team][round] == 'bye':
                # Change the bye to the new team.
                results2[team][round] = num_teams - 1
                results2[num_teams - 1][round] = team
            else:
                results2[team][round] = results[team][round]

    return results2


# In[53]:


def generate_round_robin(num_teams):
    if num_teams % 2 == 0:
        return generate_round_robin_even(num_teams)
    else:
        return generate_round_robin_odd(num_teams)


# In[77]:


def print_matrix(schedule):
    for row in schedule:
        print(row)

def print_schedule(schedule):
    num_teams = len(schedule)
    num_rounds = len(schedule[0])
    for round in range(num_rounds):
        print(f'Round {round}')
        for team1 in range(num_teams):
            team2 = schedule[team1][round]

            # Only print if it's a bye or team 1 < team 2.
            if team2 == 'bye':
                print(f'  {team1} has a bye')
            elif  team1 < team2:
                print(f'  {team1} vs. {team2}')


# In[80]:


print('Four teams:')
schedule = generate_round_robin(4)
print_matrix(schedule)
print_schedule(schedule)

print()
print('Five teams:')
print_schedule(generate_round_robin(5))


# In[ ]:





# In[ ]:




